==> p2_store-0.2.8-py3-none-any.whl: p2_store/postgresInt.py <==
import os
from psycopg2 import connect, sql, Error
import psycopg2.extras
import logging

class SQLit:

    def __init__(self):
        self.connection = connect(
                user     = os.environ.get('DB_P2STORE_USER', 'postgres'),
                password = os.environ.get('DB_P2STORE_PASSWORD', 'someLocalPassword'),
                host     = os.environ.get('DB_P2STORE_HOST', 'localhost'),
                port     = os.environ.get('DB_P2STORE_PORT', '5432'),
                database = os.environ.get('DB_P2STORE_DBNAME', 'p2store'))


    def __del__(self):
        if(self.connection):
            self.connection.close()


    def execute(self, QUERY, *data):
        if type(data) is list or type(data) is tuple and (len(data) == 1):
            data = data[0]
        logging.debug(QUERY)
        try:
            cursor = self.connection.cursor(cursor_factory = psycopg2.extras.DictCursor)
            cursor.execute(QUERY, data)
            if ('SELECT' in QUERY): # this is bad....
                record = cursor.fetchall()
                return(record)
            else:
                self.connection.commit()
                return(cursor.rowcount)
        except (Exception, Error) as error :
            logging.error("PostgreSQL error: ", error)
            raise error
    
    def execute_as_dict(self, QUERY, *data):
        if type(data) is list or type(data) is tuple and (len(data) == 1):
            data = data[0]
        logging.debug(QUERY)
        try:
            cursor = self.connection.cursor(cursor_factory = psycopg2.extras.RealDictCursor)
            cursor.execute(QUERY, data)
            if ('SELECT' in QUERY): # this is bad....
                record = cursor.fetchall()
                return(record)
            else:
                self.connection.commit()
                return(cursor.rowcount)
        except (Exception, Error) as error :
            logging.error("PostgreSQL error: ", error)
            raise error

    def select( self, table, filter ):
        """ Returns all records from table that match the filter (dict)
            or none if filter is not a dict
        """
        if type(filter) is not dict:
            logging.error("Filter must be a dict")
            return(None) 

        values = [ filter[k] for k in filter.keys()]
        filter_str = " AND ".join("{} = %s".format(k) for k in filter.keys())
        query = "SELECT * FROM {} WHERE {}".format(table, filter_str)
        return self.execute(query, values)

    def select_as_dict( self, table, filter ):
        """ Returns all records from table that match the filter (dict)
            or none if filter is not a dict
        """
        if type(filter) is not dict:
            logging.error("Filter must be a dict")
            return(None) 

        values = [ filter[k] for k in filter.keys()]
        filter_str = " AND ".join("{} = %s".format(k) for k in filter.keys())
        query = "SELECT * FROM {} WHERE {}".format(table, filter_str)
        return self.execute_as_dict(query, values)

    def update(self, table, primary_key, primary_key_value, attrs):
        if primary_key is None:
            logging.error("Error: no primary key")
            return(None)
        if type(attrs) is not dict:
            logging.error("Attributes must be a dict")
            return(None) 

        values = [ attrs[k] for k in attrs.keys()]
        values.append(primary_key_value)
        attrs_str = ", ".join("{} = %s".format(k) for k in attrs.keys())
        query = "UPDATE {} SET {} WHERE {}=%s".format(table, attrs_str, primary_key)
        return self.execute(query, values)

    
    def insert_stmt(self, table, record):
        """ insert record into table """
        fields = [field for field in record.keys()]
        stmt = sql.SQL("INSERT INTO {} ({}) VALUES ({})").format(
                sql.Identifier(table),
                sql.SQL(",").join(map(sql.Identifier, fields)),
                sql.SQL(', ').join(map(sql.Placeholder, fields)))
        return stmt

==> p2_store-0.4.5-py3-none-any.whl: p2_store/postgresInt.py <==
import os
from psycopg2 import connect, sql, Error
import psycopg2.extras
import logging

class SQLit:

    def __init__(self):
        self.log = logging.getLogger(__name__)
        try:
            self.connection = connect(
                    user     = os.environ.get('DB_P2STORE_USER', 'postgres'),
                    password = os.environ.get('DB_P2STORE_PASSWORD', 'someLocalPassword'),
                    host     = os.environ.get('DB_P2STORE_HOST', 'localhost'),
                    port     = os.environ.get('DB_P2STORE_PORT', '5432'),
                    database = os.environ.get('DB_P2STORE_DBNAME', 'p2store'),
                    connect_timeout = 10
                    )
        except psycopg2.Error as e:
            self.log.error("Error getting a connection: {}".format(e))
            raise e


    def __del__(self):
        if(self.connection):
            self.connection.close()

    def execute(self, QUERY, *data):
        if type(data) is list or type(data) is tuple and (len(data) == 1):
            data = data[0]
        self.log.debug(QUERY)
        try:
            cursor = self.connection.cursor(cursor_factory = psycopg2.extras.DictCursor)
            cursor.execute(QUERY, data)
            if ('SELECT' in QUERY): # this is bad....
                record = cursor.fetchall()
                return(record)
            else:
                self.connection.commit()
                return(cursor.rowcount)
        except (Exception, Error) as error :
            self.log.error("PostgreSQL error: ", error)
            raise error
    
    def execute_as_dict(self, QUERY, *data):
        if type(data) is list or type(data) is tuple and (len(data) == 1):
            data = data[0]
        self.log.debug(QUERY)
        try:
            cursor = self.connection.cursor(cursor_factory = psycopg2.extras.RealDictCursor)
            cursor.execute(QUERY, data)
            if ('SELECT' in QUERY): # this is bad....
                record = cursor.fetchall()
                return(record)
            else:
                self.connection.commit()
                return(cursor.rowcount)
        except (Exception, Error) as error :
            self.log.error("PostgreSQL error: ", error)
            raise error

    def select( self, table, filter ):
        """ Returns all records from table that match the filter (dict)
            or none if filter is not a dict
        """
        if type(filter) is not dict:
            self.log.error("Filter must be a dict")
            return(None) 

        values = [ filter[k] for k in filter.keys()]
        filter_str = " AND ".join("{} = %s".format(k) for k in filter.keys())
        query = "SELECT * FROM {} WHERE {}".format(table, filter_str)
        return self.execute(query, values)

    def select_as_dict( self, table, filter, limit: int=10000, offset: int=0 ):
        """ Returns all records from table that match the filter (dict)
            or none if filter is not a dict
        """
        if type(filter) is not dict:
            self.log.error("Filter must be a dict")
            return(None) 

        values = [ filter[k] for k in filter.keys()]
        values.append(limit)
        values.append(offset)
        filter_str = " AND ".join("{} = %s".format(k) for k in filter.keys())
        query = "SELECT * FROM {} WHERE {}".format(table, filter_str)
        query = query + " LIMIT %s OFFSET %s"
        return self.execute_as_dict(query, values)

    def update(self, table, primary_key, primary_key_value, attrs):
        if primary_key is None:
            self.log.error("Error: no primary key")
            return(None)
        if type(attrs) is not dict:
            self.log.error("Attributes must be a dict")
            return(None) 

        values = [ attrs[k] for k in attrs.keys()]
        values.append(primary_key_value)
        attrs_str = ", ".join("{} = %s".format(k) for k in attrs.keys())
        query = "UPDATE {} SET {} WHERE {}=%s".format(table, attrs_str, primary_key)
        return self.execute(query, values)

    
    def insert_stmt(self, table, record):
        """ insert record into table """
        fields = [field for field in record.keys()]
        stmt = sql.SQL("INSERT INTO {} ({}) VALUES ({})").format(
                sql.Identifier(table),
                sql.SQL(",").join(map(sql.Identifier, fields)),
                sql.SQL(', ').join(map(sql.Placeholder, fields)))
        return stmt

    def delete(self, table, key, value):
        self.log.debug("Delete - table: {}, key: {}, value: {}".format(table, key,
            value))
        query = "DELETE FROM {} WHERE {} = %s".format(table, key)
        try:
            cursor = self.connection.cursor()
            cursor.execute(query, (value,))
            self.connection.commit()
            return(cursor.rowcount)
        except Error as e:
            self.log.Error("Error performing query: {}".format(query))
            return None
